Clojure only.

pgmalli.impl.diff

Generated files against the database and against each other: what differs, entry by entry.

Generated files against the database and against each other: what differs, entry by entry.
raw docstring

checkclj

(check config)
(check config {:keys [db?] :or {db? true}})

What pgmalli.generate/check reports.

What pgmalli.generate/check reports.
sourceraw docstring

diffclj

(diff before after)

The differences between two generated data maps, as pgmalli.generate/diff documents them.

The differences between two generated data maps, as pgmalli.generate/diff documents them.
sourceraw docstring

staleclj

(stale config)

The differences pgmalli.generate/stale documents.

The differences pgmalli.generate/stale documents.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries