pgmalli.impl.generate

Config -> generated EDN files, one per schema.

Config: {:schemas ["public"] ; default ["public"] :out-dir "resources/pgmalli" ; default; files are <out-dir>/<schema>.edn :overrides {constraint-name schema-or-{:skip reason}} :db {:host :port :db :user :password :sslmode :psql :dir}} ; optional; psql's environment otherwise

File contents, in this order: {:schema "public" :database-version "PostgreSQL 17.6" :diagnostics [...] :registry {name schema} :unrendered [fact ...] :skipped [fact ...]}

Output is deterministic (sorted maps, pprint). Overrides that are not EDN (functions) are rejected at generation time.

Config -> generated EDN files, one per schema.

Config:
  {:schemas ["public"]           ; default ["public"]
   :out-dir "resources/pgmalli"  ; default; files are <out-dir>/<schema>.edn
   :overrides {constraint-name schema-or-{:skip reason}}
   :db {:host :port :db :user :password :sslmode :psql :dir}}  ; optional; psql's environment otherwise

File contents, in this order:
  {:schema "public" :database-version "PostgreSQL 17.6" :diagnostics [...]
   :registry {name schema} :unrendered [fact ...] :skipped [fact ...]}

Output is deterministic (sorted maps, pprint). Overrides that are not EDN (functions)
are rejected at generation time.
raw docstring

assembleclj

(assemble schema database-version facts overrides)

The file's data from the rendering of a schema's facts, in reading order: what it is, then what deserves a look, then the schemas, then what was left out.

The file's data from the rendering of a schema's facts, in reading order: what it is, then
what deserves a look, then the schemas, then what was left out.
sourceraw docstring

configclj

(config c)

Config with defaults applied. Unknown keys are an error.

Config with defaults applied. Unknown keys are an error.
sourceraw docstring

default-configclj

source

edn-stringclj

(edn-string data)
source

generate!clj

(generate! c)

Writes every schema's file. Returns {schema path}.

Writes every schema's file. Returns {schema path}.
sourceraw docstring

generatedclj

(generated {:keys [db overrides]} schema)

Generated data for one schema.

Generated data for one schema.
sourceraw docstring

generated-allclj

(generated-all c)

{schema {:path :data}} for every schema in the config.

{schema {:path :data}} for every schema in the config.
sourceraw docstring

load-file*clj

(load-file* path)
source

path-forclj

(path-for c schema)
source

cljdoc builds & hosts documentation for Clojure/Script libraries