Command line entry point. Config comes from pgmalli.edn in the working directory or the path given as second argument.
clojure -M -m pgmalli.main generate [pgmalli.edn] clojure -M -m pgmalli.main check [pgmalli.edn] ; exit 1 when files are stale bb -m pgmalli.main ...
Command line entry point. Config comes from pgmalli.edn in the working directory or the path given as second argument. clojure -M -m pgmalli.main generate [pgmalli.edn] clojure -M -m pgmalli.main check [pgmalli.edn] ; exit 1 when files are stale bb -m pgmalli.main ...
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |