Config -> generated EDN files, one per schema.
Config: {:schemas ["public"] ; default ["public"] :out-dir "resources/pgmalli" ; default; files are <out-dir>/<schema>.edn :overrides {constraint-name schema-or-{:skip reason}} :db {:host :port :db :user :password :sslmode :psql :dir}} ; optional; psql's environment otherwise
File contents, in this order: {:schema "public" :database-version "PostgreSQL 17.6" :diagnostics [...] :registry {name schema} :unrendered [fact ...] :skipped [fact ...]}
Output is deterministic (sorted maps, pprint). Overrides that are not EDN (functions) are rejected at generation time.
Config -> generated EDN files, one per schema.
Config:
{:schemas ["public"] ; default ["public"]
:out-dir "resources/pgmalli" ; default; files are <out-dir>/<schema>.edn
:overrides {constraint-name schema-or-{:skip reason}}
:db {:host :port :db :user :password :sslmode :psql :dir}} ; optional; psql's environment otherwise
File contents, in this order:
{:schema "public" :database-version "PostgreSQL 17.6" :diagnostics [...]
:registry {name schema} :unrendered [fact ...] :skipped [fact ...]}
Output is deterministic (sorted maps, pprint). Overrides that are not EDN (functions)
are rejected at generation time.(assemble schema database-version facts overrides)The file's data from the rendering of a schema's facts, in reading order: what it is, then what deserves a look, then the schemas, then what was left out.
The file's data from the rendering of a schema's facts, in reading order: what it is, then what deserves a look, then the schemas, then what was left out.
(config c)Config with defaults applied. Unknown keys are an error.
Config with defaults applied. Unknown keys are an error.
(generate! c)Writes every schema's file. Returns {schema path}.
Writes every schema's file. Returns {schema path}.
(generated {:keys [db overrides]} schema)Generated data for one schema.
Generated data for one schema.
(generated-all c){schema {:path :data}} for every schema in the config.
{schema {:path :data}} for every schema in the config.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |