The JDBC side: the transformer decoding driver and string values into the registry's types, and the row shapes next.jdbc's result set builders return.
The JDBC side: the transformer decoding driver and string values into the registry's types, and the row shapes next.jdbc's result set builders return.
(as-read registry name {:keys [qualified? kebab? nil-columns time]})The [:map ...] of a row as a JDBC result builder returns it; the options are documented on pgmalli.core/as-read.
The [:map ...] of a row as a JDBC result builder returns it; the options are documented on pgmalli.core/as-read.
(read-options builder)The reading options of a next.jdbc result set builder named by its symbol; documented on pgmalli.core/read-options.
The reading options of a next.jdbc result set builder named by its symbol; documented on pgmalli.core/read-options.
(transformer)(transformer {:keys [zone] :or {zone (java.time.ZoneId/systemDefault)}})Decodes JDBC and string values into the registry's types: java.sql.Timestamp and java.util.Date -> Instant, java.sql.Date -> LocalDate, an Instant or java.util.Date landing in a date or timestamp (without time zone) column is read in :zone, default the JVM's; JSON text in a json or jsonb column is parsed.
Decodes JDBC and string values into the registry's types: java.sql.Timestamp and java.util.Date -> Instant, java.sql.Date -> LocalDate, an Instant or java.util.Date landing in a date or timestamp (without time zone) column is read in :zone, default the JVM's; JSON text in a json or jsonb column is parsed.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |